@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::pidigits;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Shootout::pidigits::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # The Computer Language Benchmarks Game
 #   http://shootout.alioth.debian.org/
@@ -87,7 +90,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Shootout::pidigits
 
 =head1 NAME
 
@@ -97,3 +108,20 @@ Benchmark::Perl::Formance::Plugin::Shootout::pidigits - Language shootout plugin
 
 This plugin does some runs the "pidigits" benchmark from the Language
 Shootout.
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
